Enum quaint::connector::ConnectionInfo
source · pub enum ConnectionInfo {
Postgres(PostgresUrl),
Mysql(MysqlUrl),
Mssql(MssqlUrl),
Sqlite {
file_path: String,
db_name: String,
},
InMemorySqlite {
db_name: String,
},
}Expand description
General information about a SQL connection.
Variants
Postgres(PostgresUrl)
Available on crate feature
postgresql only.A PostgreSQL connection URL.
Mysql(MysqlUrl)
Available on crate feature
mysql only.A MySQL connection URL.
Mssql(MssqlUrl)
Available on crate feature
mssql only.A SQL Server connection URL.
Sqlite
Fields
Available on crate feature
sqlite only.A SQLite connection URL.
InMemorySqlite
Available on crate feature
sqlite only.Implementations
sourceimpl ConnectionInfo
impl ConnectionInfo
sourcepub fn from_url(url_str: &str) -> Result<Self>
pub fn from_url(url_str: &str) -> Result<Self>
Parse ConnectionInfo out from an SQL connection string.
Will fail if URI is invalid or the scheme points to an unsupported database.
sourcepub fn schema_name(&self) -> &str
pub fn schema_name(&self) -> &str
This is what item names are prefixed with in queries.
- In SQLite, this is the schema name that the database file was attached as.
- In Postgres, it is the selected schema inside the current database.
- In MySQL, it is the database name.
sourcepub fn username(&self) -> Option<Cow<'_, str>>
pub fn username(&self) -> Option<Cow<'_, str>>
The provided database user name. This will be None on SQLite.
sourcepub fn sql_family(&self) -> SqlFamily
pub fn sql_family(&self) -> SqlFamily
The family of databases connected.
sourcepub fn pg_bouncer(&self) -> bool
pub fn pg_bouncer(&self) -> bool
Whether the pgbouncer mode is enabled.
sourcepub fn database_location(&self) -> String
pub fn database_location(&self) -> String
A string describing the database location, meant for error messages. It will be the host and port on MySQL/Postgres, and the file path on SQLite.